import os
from pyformance import global_registry
from pscr_common.metrics import get_reporter
from pscr_common.metadata import MetadataProvider


class Metrics:
    def __init__(self, config):
        self.metrics_registry = global_registry()
        self.config = config

    def get_reporter(self):
        env = os.environ.get("ENV_ID", "unknown")
        env_meta = MetadataProvider().get_metadata()
        reporter = get_reporter(
            self.metrics_registry,
            env,
            env_meta.task_id,
            "dre_c_rule_updater",
            env_meta.image.rsplit(":", maxsplit=1)[-1],
        )
        return reporter

    def add_error_metrics(self, origin):
        self.metrics_registry.counter(f"dre_c_rule_updater.error.{origin}")

    def add_rule_size_metrics(self, size):
        self.metrics_registry.gauge("dre_c_rule_updater.rule.size").set_value(size)

    def add_dry_run_metrics(self):
        self.metrics_registry.counter("dre_c_rule_updater.dry_run")

    def health_metrics(self, size):
        self.metrics_registry.gauge("dre_c_rule_updater.health_check").set_value(size)
